@@ -5,5 +5,5 @@ from .validators import validate_node
 
 
 def validate(nodes: List[dict]):
-    with ThreadPoolExecutor(max_workers=1000) as executor:
+    with ThreadPoolExecutor() as executor:
         return list(executor.map(validate_node, nodes))
